FirestoreAdminSource<T> class
Firestore implementation of Source using pkg:google_cloud_firestore.
- Inheritance
-
- Object
- DataContract<
T> - FirestoreAdminSource
Constructors
Properties
-
bindings
↔ Bindings<
T> -
All meta information about
Tnecessary to plug arbitrary data types into aRepository.getter/setter pairinherited -
collection
→ CollectionReference<
DocumentData> -
The Firestore collection for this source.
no setter
- collectionName → String
-
The collection name from the Firestore console.
final
- firestore → Firestore
-
Firestore instance.
final
- hasBindings → bool
-
Proxy getter for whether
bindingshas been initialized, either by being passed in via this constructor or by being set by theSourceList.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
-
onCreateServerTimestampFields
→ List<
String> -
Fields that should be set to
FieldValue.serverTimestampon create.final -
onUpdateServerTimestampFields
→ List<
String> -
Fields that should be set to
FieldValue.serverTimestampon every write.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceType ↔ SourceType
-
Indicator for whether this
Sourceloads data from a store on-device, or off-device.getter/setter pair -
supportedOperations
→ Set<
SourceOperationType> -
The operations supported by this loader instance.
Defaults to standard CRUD operations.
no setterinherited
Methods
-
delete(
DeleteOperation< T> operation) → Future<DeleteResult< T> > -
deleteItem(
DeleteOperation< T> operation) → Future<DeleteResult< T> > -
Clears an item with the given
DeleteOperation.itemIdif one exists.inherited -
deleteItems(
DeleteListOperation< T> operation) → Future<DeleteResult< T> > -
Clears all items matching the given
DeleteListOperation.details.inherited -
getById(
ReadOperation< T> operation) → Future<ReadResult< T> > -
Loads the instance of
Twhose primary key is found atReadOperation.itemId.override -
getByIds(
ReadByIdsOperation< T> operation) → Future<ReadListResult< T> > -
Loads all instances of
Twhose primary key is in the set atReadByIdsOperation.itemIds.override -
getItems(
ReadListOperation< T> operation) → Future<ReadListResult< T> > -
Loads all instances of
Tthat satisfy any filtes or pagination onReadListOperation.details.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
raw(
String id, Json map) → Future< void> -
Merges an arbitrary
Jsonmap into the document withid. -
setItem(
WriteOperation< T> operation) → Future<WriteResult< T> > -
Persists
WriteOperation.item.override -
setItems(
WriteListOperation< T> operation) → Future<WriteListResult< T> > -
Persists all
WriteListOperation.items.override -
supports(
SourceOperationType type) → bool -
Returns whether this instance supports the given
SourceOperationType.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
watch(
WatchOperation< T> operation) → Stream<ReadResult< T> > -
Opens a live stream which will yield the current matching model
periodically via a
ReadResult. -
watchByIds(
WatchByIdsOperation< T> operation) → Stream<ReadListResult< T> > -
Opens a live stream which will yield the current matching models
periodically via a
ReadListResult. -
watchList(
WatchListOperation< T> operation) → Stream<ReadListResult< T> > -
Opens a live stream which will yield the current matching models
periodically via a
ReadListResult.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
cleanData(
Json data) → Json -
Converts Firebase
Timestampvalues into ISO 8601 strings. -
cleanDataForWrite(
Json data) → Json -
Converts Dart DateTimes into Firebase
Timestampvalues.